@@ -58,7 +58,7 @@ def get_http_host_ip() -> str:
     return urlsplit('//' + http_host).hostname
 
 
-def update_config(run_id: int, team_name: str, exp_name: str, config_item_dict: list):
+def update_config(run_id: int, team_name: str, exp_name: str, config_item_list: list(Tuple)):
     def makeItem(item):
         key, value = item
         if isinstance(value, int):
@@ -78,11 +78,11 @@ def update_config(run_id: int, team_name: str, exp_name: str, config_item_dict:
 
     # client 정보 추가
     import deepdriver.version as version
-    config_item_dict.append(('cliVer', version.__version__))
-    config_item_dict.append(('pythonVer', util.get_python_version()))
+    config_item_list.append(('cliVer', version.__version__))
+    config_item_list.append(('pythonVer', util.get_python_version()))
 
 
-    item = map(makeItem, config_item_dict)
+    item = map(makeItem, config_item_list)
     rsp: UpdateConfigResponse = get_stub().update_config(UpdateConfigRequest(
         runId=run_id,
         item=item,
